<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:x="http://www.w3.org/TR/xpath">
    <xsl:output method="xml" indent="yes" xalan:indent-amount="4" xmlns:xalan="http://xml.apache.org/xslt"/>
    <xsl:strip-space elements="*"/>

    <xsl:template match="/x:*/x:*/x:*[not(self::x:AbsoluteLocationPath)]">
        <xsl:message terminate="yes">This adaptor only supports absolute path</xsl:message>
    </xsl:template>
    <xsl:template match="x:NameStep[@axis!='child']">
        <xsl:message terminate="yes">This adaptor only supports child axis</xsl:message>
    </xsl:template>
    <xsl:template match="x:Predicate[ancestor::x:Predicate]">
        <xsl:message terminate="yes">This adaptor does not support nested predicates</xsl:message>
    </xsl:template>
    <xsl:template match="x:AbsoluteLocationPath[ancestor::x:Predicate]">
        <xsl:message terminate="yes">This adaptor does not support absolute path in predicates</xsl:message>
    </xsl:template>
    <xsl:template match="x:Function[@s1!='not']">
        <xsl:message terminate="yes">This adaptor does not yet support functions (please let us know if you need it)</xsl:message>
    </xsl:template>
    <xsl:template match="x:AllNodeStep">
        <xsl:message terminate="yes">This adaptor does not support unnamed node</xsl:message>
    </xsl:template>
    <xsl:template match="x:CommentNodeStep | x:ProcessingInstructionNodeStep | x:UnionExpr | x:VariableReference">
        <xsl:message terminate="yes">This adaptor does not support <xsl:value-of select="local-name()"/></xsl:message>
    </xsl:template>

    <xsl:template match="x:AbsoluteLocationPath | x:RelativeLocationPath">
        <xsl:copy>
            <xsl:apply-templates/>
        </xsl:copy>
    </xsl:template>

    <xsl:template match="x:NameStep[@axis='child']">
        <xsl:copy>
            <xsl:copy-of select="@prefix | @localName"/>
            <xsl:apply-templates/>
        </xsl:copy>
    </xsl:template>

    <xsl:template match="x:Predicate">
        <xsl:apply-templates select="x:*[last()]"/>
    </xsl:template>
    <xsl:template match="x:AndExpr | x:OrExpr">
        <xsl:copy>
            <xsl:apply-templates select="(x:PathExpr|x:AndExpr|x:OrExpr|x:NotExpr)[last()]/preceding-sibling::x:*[1]"/>
            <xsl:apply-templates select="x:*[last()]"/>
        </xsl:copy>
    </xsl:template>
    <xsl:template match="x:Function[@s1='not']">
        <x:NotExpr>
            <xsl:apply-templates select="x:*[last()]"/>
        </x:NotExpr>
    </xsl:template>

    <xsl:template match="x:EqualityExpr | x:RelationalExpr">
        <x:Comparison>
            <xsl:copy-of select="@symbol"/>
            <xsl:apply-templates select="preceding-sibling::x:*[1]"/>
            <xsl:apply-templates select="x:*"/>
        </x:Comparison>
    </xsl:template>
    <xsl:template match="x:UnaryExpr">
        <xsl:copy>
            <xsl:copy-of select="@symbol"/>
            <xsl:apply-templates select="x:*"/>
        </xsl:copy>
    </xsl:template>

    <xsl:template match="x:Literal">
        <xsl:copy>
            <xsl:value-of select="@s"/>
        </xsl:copy>
    </xsl:template>
    <xsl:template match="x:Number">
        <xsl:copy>
            <xsl:value-of select="@i"/>
        </xsl:copy>
    </xsl:template>
</xsl:stylesheet>